use std::borrow::Cow;

use quick_xml::{events::attributes::Attribute, name::QName};

use super::WriteElement;

/// [feColorMatrix](https://www.w3.org/TR/SVG11/filters.html#feColorMatrixElement)
#[derive(Debug)]
pub struct ColorMatrix {
    cm_type: ColorMatrixType,
}

impl ColorMatrix {
    pub fn new(cm_type: ColorMatrixType) -> Self {
        Self { cm_type }
    }
}

impl WriteElement for ColorMatrix {
    fn attrs(&self) -> Vec<quick_xml::events::attributes::Attribute> {
        match &self.cm_type {
            ColorMatrixType::Matrix(v) => vec![Attribute {
                key: QName(b"values"),
                value: Cow::from(
                    v.iter()
                        .map(std::string::ToString::to_string)
                        .reduce(|mut acc, e| {
                            acc.push(' ');
                            acc.push_str(&e);
                            acc
                        })
                        .expect("Should be able to concatenate the thingies")
                        .into_bytes(),
                ),
            }],
            ColorMatrixType::Saturate(v) | ColorMatrixType::HueRotate(v) => vec![Attribute {
                key: QName(b"values"),
                value: Cow::from(v.to_string().into_bytes()),
            }],
            ColorMatrixType::LuminanceToAlpha => Vec::new(),
        }
    }

    fn tag_name(&self) -> &'static str {
        "feColorMatrix"
    }
}

#[derive(Debug)]
pub enum ColorMatrixType {
    Matrix(Box<[f32; 20]>),
    Saturate(f32),
    HueRotate(f32),
    LuminanceToAlpha,
}
