use std::{borrow::Cow, fmt::Display};

use quick_xml::{events::attributes::Attribute, name::QName};

use super::WriteElement;

/// [feMorphology](https://www.w3.org/TR/SVG11/filters.html#feMorphologyElement)
#[derive(Debug)]
pub struct Morphology {
    operator: Operator,
    radius: (f32, f32),
}

impl WriteElement for Morphology {
    fn attrs(&self) -> Vec<quick_xml::events::attributes::Attribute> {
        vec![
            Attribute {
                key: QName(b"operator"),
                value: Cow::from(self.operator.to_string().into_bytes()),
            },
            Attribute {
                key: QName(b"radius"),
                value: Cow::from(format!("{} {}", self.radius.0, self.radius.1).into_bytes()),
            },
        ]
    }

    fn tag_name(&self) -> &'static str {
        "feMorphology"
    }
}

#[derive(Debug)]
enum Operator {
    Erode,
    Dilate,
}

impl Display for Operator {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        f.write_str(match self {
            Operator::Erode => "erode",
            Operator::Dilate => "dilate",
        })
    }
}
