use std::borrow::Cow;

use quick_xml::{events::attributes::Attribute, name::QName};

use super::WriteElement;

/// [feOffset](https://www.w3.org/TR/SVG11/filters.html#feOffsetElement)
#[derive(Debug)]
pub struct Offset {
    dx: f32,
    dy: f32,
}

impl Offset {
    pub fn new(dx: f32, dy: f32) -> Self {
        Self { dx, dy }
    }
}

impl WriteElement for Offset {
    fn attrs(&self) -> Vec<quick_xml::events::attributes::Attribute> {
        vec![
            Attribute {
                key: QName(b"dx"),
                value: Cow::from(self.dx.to_string().into_bytes()),
            },
            Attribute {
                key: QName(b"dy"),
                value: Cow::from(self.dy.to_string().into_bytes()),
            },
        ]
    }

    fn tag_name(&self) -> &'static str {
        "feOffset"
    }
}
